# Generated by Django 3.0.6 on 2020-05-13 22:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0003_auto_20200506_1813'),
    ]

    operations = [
        migrations.AlterField(
            model_name='antecedente',
            name='expediente_modificado',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='expediente_modificado', to='gea.Expediente'),
        ),
    ]



# Generated by Django 3.0.6 on 2020-05-06 21:13

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0002_auto_20200505_1940'),
    ]

    operations = [
        migrations.AlterField(
            model_name='persona',
            name='documento',
            field=models.IntegerField(blank=True, default=None, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='persona',
            name='lugar',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='gea.Lugar'),
        ),
        migrations.AlterField(
            model_name='persona',
            name='tipo_doc',
            field=models.SmallIntegerField(blank=True, choices=[(0, 'DNI'), (1, 'LC'), (2, 'LE'), (3, 'Otro')], default=None, null=True),
        ),
    ]



import unicodedata

from django.contrib import admin
from django.db import models
from django.db.models import Q
from django.forms import TextInput
from django.utils.safestring import mark_safe
from django.utils.translation import gettext_lazy as _

from nested_admin import NestedModelAdmin, NestedStackedInline, NestedTabularInline

from .models import (
    Antecedente,
    Catastro,
    CatastroLocal,
    Circunscripcion,
    Comprobante,
    Dp,
    Ds,
    Expediente,
    ExpedienteLugar,
    ExpedientePartida,
    ExpedientePersona,
    Lugar,
    Objeto,
    Pago,
    Partida,
    PartidaDominio,
    Persona,
    Presupuesto,
    Profesional,
    Sd,
    Titulo,
    Zona,
)

# -----------------------------------------------------------------------------
# Custom Filters
# -----------------------------------------------------------------------------


# Personas
class CantidadDeExpedientesPorPersonaFilter(admin.SimpleListFilter):
    title = _("cantidad de expedientes por persona")
    parameter_name = "expedientes"

    def lookups(self, request, model_admin):
        return (
            ("0", _("Ninguno")),
            ("1", _("1")),
            ("2", _("2")),
            ("3", _("3")),
            ("4+", _("4 o +")),
        )

    def queryset(self, request, queryset):
        qs = queryset.annotate(entry_count=models.Count("expedientepersona"))
        if self.value() == "0":
            qs = qs.filter(entry_count=0)
            return qs
        if self.value() == "1":
            qs = qs.filter(entry_count=1)
            return qs
        if self.value() == "2":
            qs = qs.filter(entry_count=2)
            return qs
        if self.value() == "3":
            qs = qs.filter(entry_count=3)
            return qs
        if self.value() == "4+":
            qs = qs.filter(entry_count__gt=3)
            return qs


# Objetos
class CantidadDeExpedientesPorObjetoFilter(admin.SimpleListFilter):
    title = _("cantidad de expedientes por objeto")
    parameter_name = "expedientes"

    def lookups(self, request, model_admin):
        return (
            ("0", _("Ninguno")),
            ("10", _("entre 1 y 10")),
            ("50", _("entre 10 y 50")),
            ("100", _("entre 50 y 100")),
            ("100+", _("100 o +")),
        )

    def queryset(self, request, queryset):
        qs = queryset.annotate(entry_count=models.Count("expediente"))
        if self.value() == "0":
            qs = qs.filter(entry_count=0)
            return qs
        if self.value() == "10":
            qs = qs.filter(entry_count__gte=1).filter(entry_count__lt=10)
            return qs
        if self.value() == "50":
            qs = qs.filter(entry_count__gte=10).filter(entry_count__lt=50)
            return qs
        if self.value() == "100":
            qs = qs.filter(entry_count__gte=50).filter(entry_count__lt=100)
            return qs
        if self.value() == "100+":
            qs = qs.filter(entry_count__gte=100)
            return qs


# Expedientes
class InscriptoFilter(admin.SimpleListFilter):
    # Human-readable title which will be displayed in the
    # right admin sidebar just above the filter options.
    title = _("inscripto")

    # Parameter for the filter that will be used in the URL query.
    parameter_name = "inscripto"

    def lookups(self, request, model_admin):
        """
        Returns a list of tuples. The first element in each
        tuple is the coded value for the option that will
        appear in the URL query. The second element is the
        human-readable name for the option that will appear
        in the right sidebar.
        """
        return (
            ("si", _("Si")),
            ("no", _("No")),
        )

    def queryset(self, request, queryset):
        """
        Returns the filtered queryset based on the value
        provided in the query string and retrievable via
        `self.value()`.
        """
        # Compare the requested value (either '80s' or '90s')
        # to decide how to filter the queryset.
        if self.value() == "si":
            return queryset.filter(inscripcion_numero__isnull=False)
        if self.value() == "no":
            return queryset.filter(inscripcion_numero__isnull=True)


class TieneOrdenFilter(admin.SimpleListFilter):
    title = _("tiene orden")
    parameter_name = "orden"

    def lookups(self, request, model_admin):
        return (
            ("si", _("Si")),
            ("no", _("No")),
        )

    def queryset(self, request, queryset):
        if self.value() == "si":
            return queryset.filter(orden_numero__isnull=False)
        if self.value() == "no":
            return queryset.filter(orden_numero__isnull=True)


class TieneOrdenPendienteFilter(admin.SimpleListFilter):
    title = _("orden pendiente")
    parameter_name = "orden_pendiente"

    def lookups(self, request, model_admin):
        return (
            ("si", _("Si")),
            ("no", _("No")),
        )

    def queryset(self, request, queryset):
        if self.value() == "si":
            return queryset.filter(
                orden_numero__isnull=False, inscripcion_numero__isnull=True
            )
        if self.value() == "no":
            return queryset.exclude(
                orden_numero__isnull=False, inscripcion_numero__isnull=True
            )


class TieneAntecedentesFilter(admin.SimpleListFilter):
    title = _("tiene antecedentes")
    parameter_name = "antecedente"

    def lookups(self, request, model_admin):
        return (
            ("si", _("Si")),
            ("no", _("No")),
        )

    def queryset(self, request, queryset):
        if self.value() == "si":
            return queryset.filter(antecedente__isnull=False)
        if self.value() == "no":
            return queryset.filter(antecedente__isnull=True)


class TieneObjetoFilter(admin.SimpleListFilter):
    title = _("tiene objeto")
    parameter_name = "objeto"

    def lookups(self, request, model_admin):
        return (
            ("si", _("Si")),
            ("no", _("No")),
        )

    def queryset(self, request, queryset):
        if self.value() == "si":
            return queryset.filter(objetos__isnull=False)
        if self.value() == "no":
            return queryset.filter(objetos__isnull=True)


class TienePlanoFilter(admin.SimpleListFilter):
    title = _("tiene plano cargado")
    parameter_name = "plano_ruta"

    def lookups(self, request, model_admin):
        return (
            ("si", _("Si")),
            ("no", _("No")),
        )

    def queryset(self, request, queryset):
        if self.value() == "si":
            return queryset.exclude(plano_ruta__isnull=True)
        if self.value() == "no":
            return queryset.exclude(plano_ruta__isnull=False)


class TieneSetFilter(admin.SimpleListFilter):
    title = _("tiene informe cargado")
    parameter_name = "informe"

    def lookups(self, request, model_admin):
        return (
            ("si", _("Si")),
            ("no", _("No")),
        )

    def queryset(self, request, queryset):
        if self.value() == "si":
            return queryset.exclude(set_ruta__isnull=True, set_ruta__exact="")
        if self.value() == "no":
            return queryset.filter(Q(set_ruta__isnull=True) | Q(set_ruta__exact=""))


# -----------------------------------------------------------------------------
# Inlines
# -----------------------------------------------------------------------------

# Expedientes
class CatastroLocalInline(NestedTabularInline):
    classes = ("extrapretty", "collapse")
    model = CatastroLocal
    extra = 0
    formfield_overrides = {
        models.CharField: {"widget": TextInput(attrs={"size": "10"})},
    }


class ExpedienteLugarInline(NestedStackedInline):
    classes = ["extrapretty"]
    model = ExpedienteLugar
    extra = 0
    inlines = [CatastroLocalInline]


class ExpedientePersonaInline(NestedStackedInline):
    classes = ["extrapretty"]
    model = ExpedientePersona
    extra = 0
    ordering = ["-comitente"]


class CatastroInline(NestedTabularInline):
    classes = ("extrapretty", "collapse")
    model = Catastro
    extra = 0
    formfield_overrides = {
        models.CharField: {"widget": TextInput(attrs={"size": "10"})},
    }


class ExpedientePartidaInline(NestedStackedInline):
    classes = ["extrapretty"]
    model = ExpedientePartida
    extra = 0
    inlines = [CatastroInline]
    exclude = ["set_ruta"]


class AntecedenteInline(NestedTabularInline):
    classes = ["extrapretty"]
    model = Antecedente
    fk_name = "expediente"
    extra = 0
    ordering = ["-expediente_modificado", "-inscripcion_numero"]


# -----------------------------------------------------------------------------
# Admin
# -----------------------------------------------------------------------------


@admin.register(Expediente)
class ExpedienteAdmin(NestedModelAdmin):
    filter_horizontal = ["objetos", "profesionales_firmantes"]
    fieldsets = [
        (
            None,
            {
                "fields": [("id", "fecha_plano", "created", "modified")],
                "classes": ("extrapretty"),
            },
        ),
        ("Estado", {"fields": [("fecha_medicion",)], "classes": ("extrapretty")},),
        (
            "SCIT - Servicio de Catastro e Información Territorial",
            {
                "fields": [
                    (
                        "inscripcion_numero",
                        "inscripcion_fecha",
                        "duplicado",
                        "sin_inscripcion",
                    )
                ],
                "classes": ("extrapretty"),
            },
        ),
        (
            "Orden de Trabajo CoPA",
            {"fields": [("orden_numero", "orden_fecha")], "classes": ("extrapretty"),},
        ),
        (
            "Otros",
            {
                "fields": [("cancelado", "cancelado_por"), ("plano_ruta", "ver_plano")],
                "classes": ("extrapretty", "collapse"),
            },
        ),
        ("Objetos", {"fields": [("objetos")], "classes": ("extrapretty")}),
        (
            "Profesionales Firmantes",
            {"fields": [("profesionales_firmantes")], "classes": ("extrapretty"),},
        ),
    ]
    readonly_fields = ("created", "modified", "ver_plano")
    inlines = [
        ExpedienteLugarInline,
        ExpedientePersonaInline,
        ExpedientePartidaInline,
        AntecedenteInline,
    ]
    list_display = (
        "id",
        # "created",
        "fecha_medicion",
        # "fecha_plano",
        "inscripcion_numero",
        "inscripcion_fecha",
        "duplicado",
        "sin_inscripcion",
        "orden_numero",
        # "orden_fecha",
        "cancelado",
        # "ver_plano",
    )
    list_editable = (
        # "fecha_medicion",
        # "fecha_plano",
        # "inscripcion_numero",
        # "inscripcion_fecha",
        # "duplicado",
        # "orden_numero",
        # "orden_fecha",
        # "sin_inscripcion",
        # "cancelado",
        # "plano_ruta",
    )
    list_filter = [
        "profesionales_firmantes",
        InscriptoFilter,
        "duplicado",
        "sin_inscripcion",
        TieneOrdenFilter,
        TieneOrdenPendienteFilter,
        "cancelado",
        "cancelado_por",
        TienePlanoFilter,
        "expedientelugar__lugar__nombre",
        "expedientelugar__catastrolocal__seccion",
        "expedientelugar__catastrolocal__manzana",
        "expedientelugar__catastrolocal__parcela",
        "expedientepersona__usufructo",
        TieneObjetoFilter,
        TieneAntecedentesFilter,
    ]
    search_fields = [
        "id",
        "fecha_plano",
        "inscripcion_numero",
        "inscripcion_fecha",
        "orden_numero",
        "orden_fecha",
        "cancelado_por",
        "expedientelugar__lugar__nombre",
        "expedientepersona__persona__apellidos",
        "expedientepersona__persona__nombres",
        "expedientepersona__persona__apellidos_alternativos",
        "expedientepersona__persona__nombres_alternativos",
        "profesionales_firmantes__apellidos",
        "profesionales_firmantes__nombres",
        "objetos__nombre",
        "expedientepartida__partida__pii",
        "antecedente__expediente_modificado__id",
        "antecedente__inscripcion_numero",
    ]
    actions_on_bottom = True
    date_hierarchy = "inscripcion_fecha"
    list_per_page = 20
    save_on_top = True

    def ver_plano(self, obj):
        if obj.plano_ruta != "" and obj.plano_ruta is not None:
            return mark_safe(f'<a href="{obj.plano_ruta}">{obj.inscripcion_numero}</a>')
        else:
            return None

    ver_plano.short_description = "Ver plano"
    ver_plano.admin_order_field = "plano_ruta"


def strip_accents(s):
    return "".join(
        c for c in unicodedata.normalize("NFD", s) if unicodedata.category(c) != "Mn"
    )


@admin.register(Antecedente)
class AntecedenteAdmin(admin.ModelAdmin):
    list_filter = [
        "duplicado",
        TienePlanoFilter,
    ]
    list_display = (
        "expediente",
        "expediente_modificado",
        "inscripcion_numero",
        "duplicado",
        "observacion",
    )
    list_editable = (
        # 'expediente_modificado',
        # 'inscripcion_numero',
        # 'duplicado',
        # 'observacion',
        # 'plano_ruta'
    )
    search_fields = [
        "expediente__id",
        "expediente_modificado__id",
        "inscripcion_numero",
        "duplicado",
        "observacion",
    ]
    actions_on_bottom = True
    list_per_page = 20
    save_on_top = True
    ordering = ["expediente", "-expediente_modificado", "inscripcion_numero"]

    def ver_plano(self, obj):
        if obj.plano_ruta != "" and obj.plano_ruta is not None:
            return mark_safe(f'<a href="{obj.plano_ruta}">{obj.inscripcion_numero}</a>')
        else:
            return None

    ver_plano.short_description = "Ver plano"
    ver_plano.admin_order_field = "inscripcion_plano"


@admin.register(Catastro)
class CatastroAdmin(admin.ModelAdmin):
    list_filter = ["zona", "seccion", "poligono", "manzana", "parcela", "subparcela"]
    search_fields = ["zona", "seccion", "poligono", "manzana", "parcela", "subparcela"]
    actions_on_bottom = True
    list_per_page = 20
    save_on_top = True
    ordering = ["zona", "seccion", "poligono", "manzana", "parcela", "subparcela"]


@admin.register(CatastroLocal)
class CatastroLocalAdmin(NestedModelAdmin):
    list_display = (
        "seccion",
        "manzana",
        "parcela",
        "subparcela",
        "suburbana",
        "poligono",
    )
    list_filter = ["seccion", "manzana"]
    search_fields = [
        "seccion",
        "manzana",
        "parcela",
        "subparcela",
        "suburbana",
        "poligono",
        "expediente_lugar__expediente__id",
        "expediente_lugar__lugar__nombre",
    ]
    actions_on_bottom = True
    list_per_page = 20
    save_on_top = True
    ordering = ["seccion", "manzana", "parcela", "subparcela", "suburbana", "poligono"]


@admin.register(Circunscripcion)
class CircunscripcionAdmin(admin.ModelAdmin):
    list_display = ("id", "nombre", "orden")
    # list_editable = ('nombre', 'orden')
    search_fields = ["id", "nombre", "orden"]
    actions_on_bottom = True
    save_on_top = True


@admin.register(Dp)
class DpAdmin(admin.ModelAdmin):
    list_display = (
        "dp",
        "nombre",
        "habitantes",
        "superficie",
        "cabecera",
        "circunscripcion",
    )
    list_filter = ["circunscripcion", "circunscripcion__orden"]
    search_fields = [
        "dp",
        "nombre",
        "habitantes",
        "superficie",
        "cabecera",
        "circunscripcion__nombre",
    ]
    actions_on_bottom = True
    save_on_top = True


@admin.register(Ds)
class DsAdmin(admin.ModelAdmin):
    list_display = ("id", "dp", "distrito", "nombre")
    list_filter = ["dp", "dp__nombre"]
    search_fields = ["dp__nombre", "ds", "nombre"]
    actions_on_bottom = True
    save_on_top = True


@admin.register(Sd)
class SdAdmin(admin.ModelAdmin):
    list_display = ("id", "dp", "ds", "subdistrito", "dp_nombre", "ds_nombre", "nombre")
    list_filter = ["ds__dp", "ds__dp__nombre", "ds", "ds__nombre"]
    search_fields = ["ds__dp__nombre", "ds__nombre", "sd", "nombre"]
    actions_on_bottom = True
    save_on_top = True


@admin.register(ExpedientePartida)
class ExpedientePartidaAdmin(admin.ModelAdmin):
    inlines = [CatastroInline]
    list_display = ("expediente", "partida", "set_ruta")
    list_filter = [
        TieneSetFilter,
    ]
    search_fields = [
        "expediente__id",
        "partida__pii",
    ]
    list_select_related = True
    list_per_page = 20


@admin.register(Lugar)
class LugarAdmin(admin.ModelAdmin):
    list_display = ("nombre", "observacion")
    list_editable = ("observacion",)
    search_fields = ["nombre", "observacion"]
    actions_on_bottom = True
    save_on_top = True


@admin.register(Objeto)
class ObjetoAdmin(admin.ModelAdmin):
    list_filter = [CantidadDeExpedientesPorObjetoFilter]
    search_fields = ["nombre"]
    actions_on_bottom = True
    save_on_top = True


class PartidaDominioInline(admin.TabularInline):
    model = PartidaDominio
    extra = 0


@admin.register(Partida)
class PartidaAdmin(admin.ModelAdmin):
    fieldsets = [
        (None, {"fields": [("sd", "pii", "subpii", "api")]}),
    ]
    readonly_fields = ("api",)
    inlines = [PartidaDominioInline]
    # list_display = ('id', 'sd', 'pii', 'subpii', 'api')
    list_filter = ["sd__ds__dp__nombre"]
    search_fields = ["pii", "sd__nombre", "sd__ds__nombre", "sd__ds__dp__nombre"]
    actions_on_bottom = True
    save_on_top = True
    list_per_page = 20
    list_select_related = True


@admin.register(Persona)
class PersonaAdmin(admin.ModelAdmin):
    fieldsets = [
        (
            None,
            {
                "fields": [
                    ("apellidos", "nombres"),
                    ("apellidos_alternativos", "nombres_alternativos"),
                ]
            },
        ),
        (
            "Contacto",
            {"fields": [("domicilio", "lugar"), ("telefono", "celular"), "email"]},
        ),
        ("DNI/CUIT/CUIL/CDI", {"fields": [("tipo_doc", "documento"), "cuit_cuil"]}),
    ]
    inlines = [ExpedientePersonaInline]
    list_display = (
        "nombre_completo",
        "domicilio",
        "lugar",
        "show_telefono",
        "celular",
        "email",
        "show_tipo_doc",
        "documento",
        "show_cuit",
    )
    list_filter = [CantidadDeExpedientesPorPersonaFilter, "lugar"]
    search_fields = [
        "nombres",
        "apellidos",
        "nombres_alternativos",
        "apellidos_alternativos",
        "domicilio",
        "telefono",
        "celular",
        "email",
        "cuit_cuil",
        "expedientepersona__expediente__id",
    ]
    actions_on_bottom = True
    save_on_top = True

    def show_telefono(self, obj):
        if obj.telefono == "" or obj.telefono is None:
            if obj.nombres == "" or obj.nombres is None:
                return mark_safe(
                    '<a href="http://www.paginasblancas.com.ar/es-ar/persona/{}/santa-fe">buscar</a>'.format(
                        strip_accents(obj.apellidos.replace(".", ""))
                    )
                )
            else:
                return mark_safe(
                    '<a href="http://www.paginasblancas.com.ar/es-ar/persona/{}-{}/santa-fe">buscar</a>'.format(
                        strip_accents(obj.nombres.split(" ")[0].replace(".", "")),
                        strip_accents(obj.apellidos.split(" ")[0].replace(".", "")),
                    )
                )
        else:
            return obj.telefono

    show_telefono.short_description = "Telefono"
    show_telefono.admin_order_field = "telefono"

    def show_cuit(self, obj):
        if obj.cuit_cuil == "" or obj.cuit_cuil is None:
            nombre = strip_accents(
                obj.nombre_completo.replace(".", "")
                .replace(" SA", "")
                .replace(" SRL", "")
                .replace(" SCC", "")
                .replace(" SACIFI", "")
                .replace(" SH", "")
                .replace(" HNOS", "")
            )
            return mark_safe(
                f'<a href="http://www.cuitonline.com/search.php?q={nombre}">buscar</a>'
            )
        else:
            cuit_cuil = obj.cuit_cuil.replace("-", "")
            return mark_safe(
                f'<a href="http://www.cuitonline.com/constancia/inscripcion/{cuit_cuil}">{obj.cuit_cuil}</a>'
            )

    show_cuit.short_description = "CUIT/CUIL/CDI"
    show_cuit.admin_order_field = "cuit_cuil"


@admin.register(Profesional)
class ProfesionalAdmin(admin.ModelAdmin):
    fieldsets = [
        (None, {"fields": [("apellidos", "nombres"), ("titulo", "icopa")]}),
        (
            "Contacto",
            {
                "fields": [
                    ("domicilio", "lugar"),
                    ("telefono", "celular"),
                    ("email", "web"),
                ]
            },
        ),
        ("DNI/CUIT/CUIL/CDI", {"fields": ["cuit_cuil"]}),
        ("Otra info", {"fields": [("habilitado", "jubilado", "fallecido")]}),
    ]
    list_display = (
        "nombre_completo",
        "titulo",
        "icopa",
        "domicilio",
        "lugar",
        "telefono",
        "celular",
        "email",
        "web",
        "cuit_cuil",
    )
    list_filter = ["habilitado", "jubilado", "fallecido", "titulo__nombre", "lugar"]
    search_fields = [
        "nombres",
        "apellidos",
        "icopa",
        "domicilio",
        "telefono",
        "celular",
        "email",
        "web",
        "cuit_cuil",
    ]
    actions_on_bottom = True
    save_on_top = True


admin.site.register(Comprobante)


class PagoInline(NestedStackedInline):
    model = Pago
    extra = 0


@admin.register(Presupuesto)
class PresupuestoAdmin(NestedModelAdmin):
    fieldsets = [
        (
            None,
            {
                "fields": [
                    ("expediente"),
                    ("monto", "fecha", "porcentaje_cancelado"),
                    ("observacion"),
                ]
            },
        ),
    ]
    inlines = [PagoInline]
    list_display = (
        "expediente",
        "monto",
        "fecha",
        "porcentaje_cancelado",
        "observacion",
    )
    list_filter = ["expediente__id"]
    search_fields = ["expediente__id"]
    actions_on_bottom = True
    date_hierarchy = "fecha"
    list_per_page = 20
    save_on_top = True


admin.site.register(Titulo)


@admin.register(Zona)
class ZonaAdmin(admin.ModelAdmin):
    list_display = ("id", "descripcion")
    search_fields = ["id", "descripcion"]
    actions_on_bottom = True
    save_on_top = True



# Generated by Django 3.0.6 on 2020-05-05 22:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='profesional',
            name='cuit_cuil',
            field=models.CharField(blank=True, max_length=14, verbose_name='CUIT/CUIL'),
        ),
    ]



from django import forms

from . import gea_vars as gv
from . import models


class CaratulaForm(forms.Form):
    expte_nro = forms.IntegerField(label="Expediente Nº", widget=forms.NumberInput(attrs={"placeholder": "ej: 4300"}),)
    inmueble = forms.CharField(
        widget=forms.Textarea(attrs={"placeholder": "ej: Una fracción de terreno..."}), required=False,
    )
    matricula = forms.IntegerField(required=False)
    tomo = forms.IntegerField(required=False)
    par = forms.BooleanField(required=False)
    folio = forms.IntegerField(required=False)
    numero = forms.IntegerField(label="Número", required=False)
    fecha = forms.DateField(required=False)
    obs = forms.CharField(
        label="Observaciones",
        widget=forms.Textarea(
            attrs={
                "placeholder": "ej: Modifica el Lote Nº 1 del \
                              Plano Nº 23.456. Etc."
            }
        ),
        required=False,
    )
    FORMAT_CHOICES = (
        ("html", "HTML"),
        ("dxf", "DXF"),
    )
    fmt = forms.ChoiceField(label="Formato de salida", choices=FORMAT_CHOICES)


class SolicitudForm(forms.Form):
    expte_nro = forms.IntegerField(label="Expediente Nº", widget=forms.NumberInput(attrs={"placeholder": "ej: 4300"}),)
    circunscripcion = forms.ChoiceField(label="Circunscripción", choices=gv.CIRC, initial=gv.CIRC_DEFAULT)
    domicilio_fiscal = forms.CharField(
        max_length=40, widget=forms.TextInput(attrs={"placeholder": "ej: San Martín 430"}),
    )
    localidad = forms.ChoiceField(choices=gv.CP, initial=gv.CP_DEFAULT)
    provincia = forms.ChoiceField(choices=gv.PROV, initial=gv.PROV_DEFAULT)
    nota_titulo = forms.ChoiceField(label="Nota título", choices=gv.NOTA)
    nota = forms.CharField(
        label="Nota contenido",
        widget=forms.Textarea(attrs={"placeholder": "Ingrese el texto de la nota correspondiente"}),
        required=False,
    )


class VisacionForm(forms.Form):
    expte_nro = forms.IntegerField(label="Expediente Nº")
    lugar = forms.ChoiceField(choices=gv.LUGAR, initial=0)


#
# Buscar Plano por Nro
#
class PlanoForm(forms.Form):
    circ = forms.IntegerField(label="Circunscripción", min_value=1, max_value=2, initial=1)
    n_insc = forms.IntegerField(label="Plano Nº", min_value=1, max_value=999999)


#
# Buscar Set de Datos por PII
#
class SetForm(forms.Form):
    partida = forms.IntegerField(min_value=1, max_value=999999)
    sub_pii = forms.IntegerField(label="Subpartida", min_value=0, max_value=9999, initial=0)


#
# Calcular Digito Verificador de la PII
#
class DVAPIForm(forms.Form):
    dp = forms.IntegerField(label="DP (departamento)", min_value=1, max_value=19, initial=11)
    ds = forms.IntegerField(label="DS (distrito)", min_value=1, max_value=99, initial=8)
    sd = forms.IntegerField(label="SD (subdistrito)", min_value=0, max_value=99, initial=0)
    partida = forms.IntegerField(min_value=1, max_value=999999)
    sub_pii = forms.IntegerField(label="Subpartida", min_value=0, max_value=9999, initial=0)


#
# Consultar estado en Sistema de Información de Expedientes del SCIT
#
class SIEForm(forms.Form):
    mesa = forms.IntegerField(min_value=13401, max_value=13401, initial=13401)
    nro = forms.IntegerField(label="Número", min_value=1, max_value=9999999)
    digito = forms.IntegerField(label="Dígito", min_value=0, max_value=9, initial=0)


#
#
# Exptes x Catastro Local
#
#
class CLForm(forms.Form):
    lugar = forms.ModelChoiceField(
        queryset=models.Lugar.objects.exclude(nombre__startswith="Colonia")
        .exclude(nombre__startswith="Zona Rural")
        .exclude(nombre__startswith="Zona de Islas"),
        required=False,
    )
    seccion = forms.CharField(max_length=4, required=False)
    manzana = forms.CharField(max_length=4, required=False)
    parcela = forms.CharField(max_length=4, required=False)



# Generated by Django 3.0.6 on 2020-05-20 20:24

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0004_auto_20200513_1915'),
    ]

    operations = [
        migrations.AlterField(
            model_name='partida',
            name='sd',
            field=models.ForeignKey(blank=True, db_column='sd', default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='gea.Sd'),
        ),
        migrations.AlterField(
            model_name='partida',
            name='subpii',
            field=models.IntegerField(blank=True),
        ),
    ]



# Generated by Django 3.0.6 on 2020-05-05 22:13

from django.db import migrations, models
import django.db.models.deletion
import django_extensions.db.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Circunscripcion',
            fields=[
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('nombre', models.CharField(max_length=10)),
                ('orden', models.CharField(max_length=7)),
            ],
            options={
                'verbose_name_plural': 'circunscripciones',
                'ordering': ['id'],
            },
        ),
        migrations.CreateModel(
            name='Comprobante',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('nombre', models.CharField(max_length=50)),
            ],
        ),
        migrations.CreateModel(
            name='Dp',
            fields=[
                ('dp', models.IntegerField(primary_key=True, serialize=False)),
                ('nombre', models.CharField(max_length=50, verbose_name='nombre depto')),
                ('habitantes', models.IntegerField(blank=True)),
                ('superficie', models.IntegerField(blank=True)),
                ('cabecera', models.CharField(blank=True, max_length=50)),
                ('circunscripcion', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='gea.Circunscripcion')),
            ],
            options={
                'verbose_name_plural': 'Departamentos',
                'ordering': ['dp'],
            },
        ),
        migrations.CreateModel(
            name='Ds',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('ds', models.IntegerField()),
                ('nombre', models.CharField(max_length=50, verbose_name='nombre distrito')),
                ('dp', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='gea.Dp')),
            ],
            options={
                'verbose_name_plural': 'distritos',
                'ordering': ['dp', 'ds'],
            },
        ),
        migrations.CreateModel(
            name='Expediente',
            fields=[
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('id', models.IntegerField(primary_key=True, serialize=False, verbose_name='Expediente Nº')),
                ('fecha_plano', models.DateField(blank=True, null=True)),
                ('fecha_medicion', models.DateField(blank=True, null=True)),
                ('inscripcion_numero', models.IntegerField(blank=True, null=True, unique=True, verbose_name='SCIT inscripción Nº')),
                ('inscripcion_fecha', models.DateField(blank=True, null=True, verbose_name='Fecha inscripción')),
                ('duplicado', models.BooleanField(default=False)),
                ('orden_numero', models.IntegerField(blank=True, null=True, verbose_name='CoPA Expendiente Nº')),
                ('orden_fecha', models.DateField(blank=True, null=True, verbose_name='Fecha contrato')),
                ('sin_inscripcion', models.BooleanField(default=False)),
                ('cancelado', models.BooleanField(default=False)),
                ('cancelado_por', models.CharField(blank=True, max_length=100)),
                ('plano_ruta', models.URLField(blank=True, max_length=100)),
            ],
            options={
                'ordering': ['-id'],
            },
        ),
        migrations.CreateModel(
            name='Lugar',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nombre', models.CharField(max_length=80)),
                ('observacion', models.CharField(blank=True, max_length=255)),
            ],
            options={
                'verbose_name_plural': 'lugares',
                'ordering': ['nombre'],
            },
        ),
        migrations.CreateModel(
            name='Objeto',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nombre', models.CharField(max_length=80)),
            ],
            options={
                'ordering': ['nombre'],
            },
        ),
        migrations.CreateModel(
            name='Partida',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('pii', models.IntegerField()),
                ('subpii', models.IntegerField()),
                ('api', models.SmallIntegerField()),
            ],
            options={
                'ordering': ['pii', 'subpii'],
            },
        ),
        migrations.CreateModel(
            name='Titulo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nombre', models.CharField(max_length=30)),
            ],
            options={
                'ordering': ['nombre'],
            },
        ),
        migrations.CreateModel(
            name='Zona',
            fields=[
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('descripcion', models.CharField(max_length=50)),
            ],
            options={
                'ordering': ['id'],
            },
        ),
        migrations.CreateModel(
            name='Sd',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('sd', models.IntegerField()),
                ('nombre', models.CharField(blank=True, max_length=50, verbose_name='nombre subdistrito')),
                ('ds', models.ForeignKey(db_column='ds', on_delete=django.db.models.deletion.PROTECT, to='gea.Ds')),
            ],
            options={
                'verbose_name_plural': 'subdistritos',
                'ordering': ['ds', 'sd'],
            },
        ),
        migrations.CreateModel(
            name='Profesional',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nombres', models.CharField(max_length=50)),
                ('apellidos', models.CharField(max_length=50)),
                ('icopa', models.CharField(blank=True, max_length=8, verbose_name='ICoPA')),
                ('domicilio', models.CharField(blank=True, max_length=50)),
                ('telefono', models.CharField(blank=True, max_length=20)),
                ('celular', models.CharField(blank=True, max_length=20)),
                ('web', models.URLField(blank=True, max_length=50)),
                ('email', models.EmailField(blank=True, max_length=50)),
                ('cuit_cuil', models.CharField(blank=True, max_length=14, verbose_name='CUIT/CUIL/CDI')),
                ('habilitado', models.BooleanField(default=True)),
                ('jubilado', models.BooleanField(default=False)),
                ('fallecido', models.BooleanField(default=False)),
                ('lugar', models.ForeignKey(default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='gea.Lugar')),
                ('titulo', models.ForeignKey(default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='gea.Titulo')),
            ],
            options={
                'verbose_name_plural': 'profesionales',
                'ordering': ['apellidos', 'nombres'],
            },
        ),
        migrations.CreateModel(
            name='Presupuesto',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('monto', models.DecimalField(decimal_places=2, max_digits=8)),
                ('fecha', models.DateField()),
                ('porcentaje_cancelado', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='% cancelado')),
                ('observacion', models.CharField(blank=True, max_length=255)),
                ('expediente', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='gea.Expediente')),
            ],
            options={
                'ordering': ['expediente'],
            },
        ),
        migrations.CreateModel(
            name='Persona',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nombres', models.CharField(blank=True, max_length=100)),
                ('apellidos', models.CharField(max_length=100)),
                ('nombres_alternativos', models.CharField(blank=True, max_length=100)),
                ('apellidos_alternativos', models.CharField(blank=True, max_length=100)),
                ('domicilio', models.CharField(blank=True, max_length=50)),
                ('telefono', models.CharField(blank=True, max_length=20)),
                ('celular', models.CharField(blank=True, max_length=20)),
                ('email', models.EmailField(blank=True, max_length=50)),
                ('cuit_cuil', models.CharField(blank=True, default=None, max_length=14, null=True, unique=True, verbose_name='CUIT/CUIL/CDI')),
                ('tipo_doc', models.SmallIntegerField(blank=True, choices=[(0, 'DNI'), (1, 'LC'), (2, 'LE'), (3, 'Otro')])),
                ('documento', models.IntegerField(blank=True, default=None, unique=True)),
                ('lugar', models.ForeignKey(default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='gea.Lugar')),
            ],
            options={
                'ordering': ['apellidos', 'nombres'],
            },
        ),
        migrations.CreateModel(
            name='PartidaDominio',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tomo', models.IntegerField(blank=True)),
                ('par', models.BooleanField(default=False)),
                ('impar', models.BooleanField(default=False)),
                ('folio', models.IntegerField(blank=True)),
                ('numero', models.IntegerField(blank=True)),
                ('fecha', models.DateField(blank=True)),
                ('fecha_inscripcion_definitiva', models.DateField(blank=True)),
                ('partida', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='gea.Partida')),
            ],
            options={
                'verbose_name_plural': 'partida_dominios',
            },
        ),
        migrations.AddField(
            model_name='partida',
            name='sd',
            field=models.ForeignKey(db_column='sd', default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='gea.Sd'),
        ),
        migrations.CreateModel(
            name='Pago',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comprobante_nro', models.IntegerField()),
                ('fecha', models.DateField()),
                ('monto', models.DecimalField(decimal_places=2, max_digits=8)),
                ('porcentaje', models.DecimalField(decimal_places=2, max_digits=5)),
                ('observacion', models.CharField(blank=True, max_length=255)),
                ('comprobante', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='gea.Comprobante')),
                ('presupuesto', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='gea.Presupuesto')),
            ],
        ),
        migrations.CreateModel(
            name='ExpedientePersona',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('comitente', models.BooleanField(default=False)),
                ('propietario', models.BooleanField(default=True)),
                ('poseedor', models.BooleanField(default=False)),
                ('sucesor', models.BooleanField(default=False)),
                ('partes_indivisas_propias', models.IntegerField(blank=True)),
                ('partes_indivisas_total', models.IntegerField(blank=True)),
                ('sucesion', models.BooleanField(default=False)),
                ('nuda_propiedad', models.BooleanField(default=False)),
                ('usufructo', models.BooleanField(default=False)),
                ('expediente', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='gea.Expediente')),
                ('persona', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='gea.Persona')),
            ],
            options={
                'verbose_name': 'persona involucrada',
                'verbose_name_plural': 'personas involucradas',
                'ordering': ['persona__apellidos', 'persona__nombres'],
            },
        ),
        migrations.CreateModel(
            name='ExpedientePartida',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('set_ruta', models.URLField(blank=True, max_length=100)),
                ('expediente', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='gea.Expediente')),
                ('partida', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='gea.Partida')),
            ],
            options={
                'verbose_name': 'partida',
                'verbose_name_plural': 'partidas',
                'ordering': ['expediente', 'partida'],
            },
        ),
        migrations.CreateModel(
            name='ExpedienteLugar',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('expediente', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='gea.Expediente')),
                ('lugar', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='gea.Lugar')),
            ],
            options={
                'verbose_name': 'lugar',
                'verbose_name_plural': 'lugares',
                'ordering': ['expediente', 'lugar'],
            },
        ),
        migrations.AddField(
            model_name='expediente',
            name='objetos',
            field=models.ManyToManyField(to='gea.Objeto'),
        ),
        migrations.AddField(
            model_name='expediente',
            name='profesionales_firmantes',
            field=models.ManyToManyField(to='gea.Profesional'),
        ),
        migrations.CreateModel(
            name='CatastroLocal',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('seccion', models.CharField(blank=True, max_length=20)),
                ('manzana', models.CharField(blank=True, max_length=20)),
                ('parcela', models.CharField(blank=True, max_length=20)),
                ('subparcela', models.CharField(blank=True, max_length=20)),
                ('suburbana', models.BooleanField(default=False)),
                ('poligono', models.CharField(blank=True, max_length=20)),
                ('expediente_lugar', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='gea.ExpedienteLugar')),
            ],
            options={
                'verbose_name': 'catastro local',
                'verbose_name_plural': 'catastros locales',
            },
        ),
        migrations.CreateModel(
            name='Catastro',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('seccion', models.CharField(blank=True, max_length=10)),
                ('poligono', models.CharField(blank=True, max_length=10)),
                ('manzana', models.CharField(blank=True, max_length=10)),
                ('parcela', models.CharField(max_length=10)),
                ('subparcela', models.CharField(blank=True, max_length=10)),
                ('expediente_partida', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='gea.ExpedientePartida')),
                ('zona', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='gea.Zona')),
            ],
        ),
        migrations.CreateModel(
            name='Antecedente',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('inscripcion_numero', models.IntegerField()),
                ('duplicado', models.BooleanField(default=False)),
                ('observacion', models.CharField(blank=True, max_length=255)),
                ('plano_ruta', models.URLField(blank=True, max_length=100)),
                ('expediente', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='gea.Expediente')),
                ('expediente_modificado', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='expediente_modificado', to='gea.Expediente')),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='partida',
            unique_together={('pii', 'subpii')},
        ),
    ]



from django.urls import path

from . import views

urlpatterns = [
    # Inicio
    path("", views.Home.as_view(), name="home"),
    # About
    path("acerca/", views.About.as_view(), name="about"),
    # Catastros Locales
    path("catastros-locales/", views.CatastroLocalList.as_view(), name="catastros_locales"),
    # Expedientes
    path("expedientes/", views.ExpedienteList.as_view(), name="expedientes"),
    path("expediente/<int:pk>/", views.ExpedienteDetail.as_view(), name="expediente"),
    # Personas
    path("personas/", views.PersonaList.as_view(), name="personas"),
    path("persona/<int:pk>/", views.PersonaDetail.as_view(), name="persona"),
    # Notas
    path("solicitud/", views.solicitud, name="solicitud"),
    path("visacion/", views.visacion, name="visacion"),
    # Búsquedas
    path("plano/", views.plano, name="buscar_plano"),
    path("set/", views.set, name="buscar_set"),
    path("catastro/", views.catastro, name="buscar_catastro"),
    # Herramientas
    path("caratula/", views.caratula, name="caratula"),
    path("dvapi/", views.dvapi, name="dvapi"),
    path("sie/", views.sie, name="sie"),
]
